@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Channel.tcl,v $
-# $Date: 1998/06/05 19:34:07 $
-# $Revision: 1.18.1.159 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
+# $Date: 1998/06/12 15:04:18 $
+# $Revision: 1.18.1.162 $
 #
 #
 package provide zircon 1.18
@@ -69,7 +69,10 @@ proc setClose {this val} {
     if {[regexp {^[0-9]+$} $val]} { $this configure -closetime $val }
 }
 #
-proc clearClose {this args} { uplevel #0 set ${this}(close) 0 }
+proc clearClose {this args} {
+    uplevel #0 set ${this}(close) 0
+    [$this wid] checkAllClose
+}
 #
 proc channel_set {this flag} {
     switch $flag close {
@@ -79,6 +82,8 @@ proc channel_set {this flag} {
 	      "Enter the close time for [$this name]:" \
 	      [list [list Time $v]] [list ok "setClose $this"] \
 	      [list cancel "clearClose $this"]]
+	} {
+	    [$this wid] checkAllClose
 	}
     }
 }
@@ -158,10 +163,10 @@ proc channel_show {this args} {
   		  if {[isNotDefaultNet $net]} { append ttl "- [$net name]" }
   		  set w [$wndw name]
   		  set del {}
-  		  if {[$this open] && [$this join]} {set xc "$wndw iconify"}
+  		  if {[$this open] && [$this join]} {set xc "$wndw [$this iconify]"}
 	  }
 	}
-	$wndw configure -title $ttl
+	$wndw configure -title $ttl -iconop [$this iconify]
    	$this configure -wid $wndw -window $w
 	$wndw register $this "$this doLeave {}" $del
   	$wndw setIcon $this $wname
@@ -510,7 +515,6 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 		}
 		set cdata(closetime) $val
 		set cdata(closemsec) $ct
-		set cdata(closecount) $ct
 		switch {} $cdata(wid) {} default { $cdata(wid) checkAllClose }
 	    }
 	-buttons {
@@ -613,6 +617,7 @@ proc makeCUsers  {this net w chan rchan idx cdx look} {
 }
 #
 proc makeCTopic {this net w chan rchan idx cdx look} {
+    grid columnconfigure $w.r$idx $cdx -weight 1
     frame $w.topic -borderwidth 0
     grid columnconfigure $w.topic 1 -weight 1
     menubutton $w.topic.label -text [trans topic] -relief raised \
@@ -631,7 +636,7 @@ proc makeCTopic {this net w chan rchan idx cdx look} {
     bind $w.topic.entry <Escape> "notIdle %W $net ; $this makePalette Topic"
     bind $w.topic.entry <ButtonPress-3> "notIdle %W $net ; $this popPalette Topic %X %Y"
     $w.topic.entry configure -state disabled -width 0
-    grid $w.topic.label -column 0 -row 0
+    grid $w.topic.label
     setProps $this $w.topic.entry
     grid $w.topic.entry -column 1 -row 0 -sticky ew
     bind $w.topic.entry <Return> "sendTopic $this %W ; notIdle %W $net"
@@ -704,6 +709,8 @@ proc makeBindTopic {this} {
 #
 proc makeBindInfo {this} { } 
 #
+proc makeBindPopper {this} { }
+#
 proc makeBindFlags {this} { }
 #
 proc makeBindEntry {this} {
@@ -776,6 +783,7 @@ proc channel_remove {this usr} {
 #
 proc makeCEntry {this net w chan rchan idx cdx look} {
     global zII zNOII zLock zUnlock
+    grid columnconfigure $w.r$idx $cdx -weight 1
     set om [frame $w.cmd -borderwidth 0]
     grid columnconfigure $om 0 -weight 1
     scrollbar $om.hs -orient horizontal -command "$om.entry xview"
@@ -972,7 +980,7 @@ proc makeCFlags {this net w chan rchan idx cdx look} {
 #
 proc makeCInfo {this net w chan rchan idx cdx look} {
     grid [frame $w.cinfo -borderwidth 0] -row 0 -column $cdx -in $w.r$idx
-    grid columnconfigure $w $cdx -weight 1
+    grid columnconfigure $w.r$idx $cdx -weight 1
     foreach x [lindex $look 0] { label $w.cinfo.$x -relief flat }
 }
 #
@@ -982,17 +990,38 @@ proc makeCControl {this net w chan rchan idx cdx look} {
     foreach x [lindex $look 0] {
 	makeCtl[lindex $x 0] $this $net $w $chan $rchan [incr p] [lrange $x 1 end]
     }
+    grid columnconfigure $w.r$idx $cdx -weight 1
     grid $w.cmds -row 0 -column $cdx -sticky ew -in $w.r$idx
 }
 #
+proc rowHide {this net w idx} {
+    grid remove $w.r$idx
+    if {![winfo exists $w.phide]} {
+        grid [frame $w.phide -borderwidth 0 -relief flat] \
+	  -row 0 -column 0 -sticky nw
+    }
+    grid [frame $w.phide.u$idx -relief raised -borderwidth 2] \
+      -row 0 -column $idx -ipady 3 -ipadx 10 -sticky w
+    bind $w.phide.u$idx <1> "
+        destroy %W
+	grid $w.r$idx
+	switch {} \[winfo children $w.phide\] { destroy $w.phide }
+    "
+}
+#
+proc makeCPopper {this net w chan rchan idx cdx look} {
+    grid [frame $w.p$idx -relief raised -borderwidth 2] \
+      -row 0 -column $cdx -in $w.r$idx -sticky ns -ipadx 3
+    grid columnconfigure $w.r$idx $cdx -weight 0
+    bind $w.p$idx <1> "rowHide $this $net $w $idx"
+}
+#
 proc makeCBody {this w rchan chan net opts look} {
-    global TypeCode
     grid columnconfigure $w 0 -weight 1
     set idx 0
     foreach x $look {
 	set cdx 0
-	grid [frame $w.r$idx -borderwidth 0] -sticky nsew
-	grid columnconfigure $w.r$idx 0 -weight 1
+	grid [frame $w.r$idx -borderwidth 0] -row $idx -sticky nsew
 	foreach y $x {
 	    makeC[lindex $y 0] $this $net $w $chan $rchan \
 	      $idx $cdx [lrange $y 1 end]
