@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Classes.tcl,v $
-# $Date: 1998/05/29 13:05:08 $
-# $Revision: 1.18.1.78 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
+# $Date: 1998/06/12 15:04:20 $
+# $Revision: 1.18.1.80 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -57,6 +57,7 @@ class Channel {
     joinat	{}	{time}
     mytag	{>}	{prompt}
     logtag	{>}	{prompt}
+    iconify	{iconify} {operator}
 } {
     name	{}
     lname	{}
@@ -78,7 +79,6 @@ class Channel {
     window	{}
     wid		{}
     closemsec	0
-    closecount	0
     a		0
     i		0
     m		0
@@ -175,6 +175,7 @@ class Window {
     closetime	0
     children	{}
     timed	1
+    iconop	{iconify}
 }
 #
 class User {} {
