@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Control.tcl,v $
-# $Date: 1998/06/05 19:34:10 $
-# $Revision: 1.18.1.94 $
+# $Date: 1998/06/09 09:25:37 $
+# $Revision: 1.18.1.95 $
 #
 #
 package provide zircon 1.18
@@ -321,7 +321,7 @@ proc favecheck {menu chan} {
 proc keepLeave {chan v} {
     switch {} $v return
     [$chan window].quit.menu add command -label "[prune $v 15]" \
-      -command "$chan doLeave {$v}"
+      -command "$chan doLeave [list $v]"
     [$chan net] configure +leaves $v +confChange Channels
 }
 #
@@ -335,7 +335,7 @@ proc keepQuit {ctl v} {
     switch {} $v return
     set net [$ctl net]
     [$ctl window].quit.menu add command -label "[prune $v 15]" \
-      -command "$net doQuit {$v}"
+      -command "$net doQuit [list $v]"
     $net configure +signoffs $v +confChange Info
 }
 #
