@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Friend.tcl,v $
-# $Date: 1998/05/29 13:05:09 $
-# $Revision: 1.18.1.8 $
+# $Date: 1998/06/09 09:25:40 $
+# $Revision: 1.18.1.9 $
 #
 package provide zircon 1.18
 #
@@ -9,12 +9,14 @@ package provide zircon 1.18
 #
 #
 proc Friend_save {desc net} {
+    upvar #0 Configure.Friend defval
     set cm 1
     foreach x [$net friends] {
 	set ln [list Friend [$x nick]]
-	if {![$x menu]} { append ln " -menu 0"}
-	if {![$x notify]} { append ln " -notify 0" }
-	switch {} [$x id] {} default {append ln " -id {[$x id]}"}
+	foreach y [array names defval] {
+	    switch -- [$x $y] $defval($y) continue
+	    append ln " -$y [list [$x $y]]"
+	}
 	if {$cm} { puts $desc "#\n# Users\n#" ; set cm 0 }
 	puts $desc $ln
     }
