@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/List.tcl,v $
-# $Date: 1998/04/29 11:47:01 $
-# $Revision: 1.18.1.9 $
+# $Date: 1998/05/22 12:53:13 $
+# $Revision: 1.18.1.11 $
 #
 package provide zircon 1.18
 #
@@ -60,18 +60,18 @@ proc list_show {this} {
 	checkbutton $w.filter.private -variable ${net}(showPrivate) \
 	  -text [trans private]
 	checkbutton $w.filter.topic -variable ${net}(topicOnly) \
-	  -text [trans {With Topic}]
+	  -text [trans {with topic}]
 	checkbutton $w.filter.sorted -variable ${net}(sorted) \
 	  -text [trans sorted] -command "allowSBs $net $w"
 	checkbutton $w.filter.nocase -variable ${net}(nocase) \
-	  -text {Ignore Case} -state disabled
+	  -text [trans nocase] -state disabled
 	radiobutton $w.filter.names -variable ${net}(sortNames) \
-	  -value 1 -text {By Name} -state disabled
+	  -value 1 -text [trans {by name}] -state disabled
 	radiobutton $w.filter.users -variable ${net}(sortNames) \
-	  -value 0 -text {By Users} -state disabled
+	  -value 0 -text [trans {by users}] -state disabled
 	allowSBs $net $w
 	scale $w.filter.minm \
-	  -from 1 -to 25 -label {Minimum Number of Members} \
+	  -from 1 -to 25 -label [trans {minimum number of members}] \
 	  -showvalue 1 -orient horizontal \
 	  -command "set ${net}(minMembers)"
 
@@ -79,7 +79,7 @@ proc list_show {this} {
 
 	grid $w.filter.minm - - - -sticky ew
 	scale $w.filter.maxm \
-	  -from 0 -to  50 -label {Maximum Number of Members} \
+	  -from 0 -to  50 -label [trans {maximum number of members}] \
 	  -showvalue 1 -orient horizontal \
 	  -command "set ${net}(maxMembers)"
 	$w.filter.maxm set [$net maxMembers]
@@ -88,8 +88,8 @@ proc list_show {this} {
 	grid $w.filter.public $w.filter.local $w.filter.private \
 	  $w.filter.topic -sticky w
 	grid $w.filter.sorted $w.filter.nocase $w.filter.names $w.filter.users -sticky w
-	labelEntry 0 $w.filter2 {-text {Channel Pattern}} [$net listPattern] {}
-	labelEntry 0 $w.filter3 {-text {Topic Pattern}} [$net topicPattern] {}
+	labelEntry 0 $w.filter2 "-text [list [trans {channel pattern}]]" [$net listPattern] {}
+	labelEntry 0 $w.filter3 "-text [list [trans {topic pattern}]]" [$net topicPattern] {}
 	$w.filter2.entry configure -textvariable ${net}(listPattern)
 	$w.filter3.entry configure -textvariable ${net}(topicPattern)
 	makeLB $w.chn -width 20 -height 8 -exportselection 1
@@ -223,7 +223,7 @@ proc list_doit {this} {
     set net [$this net]
     set chn [$this channel]
     if {[$net undernet]} { underList $net $chn } {
-	switch {} $chn {$net q1Send LIST} default {$net qSend LIST :$chn}
+	switch {} $chn {$net q1Send LIST} default {$net q1Send "LIST :$chn"}
     }
     $this irc321
 }
