@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Net.tcl,v $
-# $Date: 1998/05/07 11:01:18 $
-# $Revision: 1.18.1.138 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
+# $Date: 1998/06/22 14:37:01 $
+# $Revision: 1.18.1.141 $
 #
 package provide zircon 1.18
 #
@@ -245,7 +245,7 @@ proc net_quit {this} {
 	set DOQ($this) 1
 	set w [mkDialog QUIT .@q$this "Quit [$this name]" \
 	  "Really quit [$this name]?" \
-	  "{message {[lindex [$this signoffs] 0]} {} palette}" \
+	  [list [list message [lindex [$this signoffs] 0] {} palette]] \
 	  "ok {$this doQuit}" "cancel {dontQuit $this }"]
 	switch {} $w {} default {catch {tkwait window $w}}
 	return $DOQ($this)
@@ -534,7 +534,7 @@ proc startReconn {net srv msg} {
 #
 proc stopReconn {this} {
     upvar #0 $this ndata
-    if [info exists $ndata(reconaft)] {
+    if [info exists ndata(reconaft)] {
 	catch {after cancel $ndata(reconaft)}
 	unset ndata(reconaft)
     }
@@ -661,39 +661,6 @@ proc net_pingTest {this} {
 #
 proc Net_list {} { global znetList ; return $znetList }
 #
-proc net_newSplit {this split} {
-    global Split TSplit Heal
-    upvar #0 $this ndata
-    $ndata(info) optText SPLIT "*** Netsplit - $split"
-    set TSplit($split) [after 600000 $this cleanSplit "{$split}"]
-    catch {after cancel $Heal($split) ; unset Heal($split)}
-    handleOn $this SPLIT $split
-    lappend ndata(splits) [list $split]
-}
-#
-proc net_cleanSplit {this h} {
-    global Split Heal TSplit
-    upvar #0 $this ndata
-    if {[info exists Split($h)]} {
-	set frnd [$this finfo]
-	foreach user $Split($h) {
-	    if {[catch {set nk [$user name]}]} continue
-	    foreach x {Chat Message Notice} {
-		switch nil [set msg [$x :: find $nk $this]] {} default {
-		    $msg heal
-		}
-	    }
-	    foreach id [$this channels] { $id remove $user }
-	    $frnd remove [$user fobj]
-	    $user deref
-	}
-	unset Split($h)
-	listkill ndata(splits) [list $h]
-    }
-    catch { after cancel $TSplit($h) ; unset TSplit($h) }
-    catch { after cancel $Heal($h) ; unset Heal($h) }
-}
-#
 proc net_setMode {this chan mode args} {
     $this MODE $chan $mode [lindex $args 0]
 }
