@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/config.tcl,v $
-# $Date: 1998/04/23 08:59:20 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/06/08 21:37:39 $
+# $Revision: 1.18.1.31 $
 #
 package provide zircon 1.18
 #
@@ -169,13 +169,13 @@ proc confAddIt {net win y typ ltyp var} {
     set val [lindex [lindex $lbdata($win) $pos] 0]
     confDABtns $net
     switch *NEW* $val {
-	mkEntryBox .@cadd "New $typ" "Enter the new $ltyp:" \
+	mkEntryBox .@cadd "[$net name] - New $typ" "Enter the new $ltyp:" \
 	  [list [list $typ {}]] [list ok "doCAN $net $pos $var $win 0"] \
 	  [list default "doCAN $net $pos $var $win 1"] \
 	  [list cancel {}]
     } default {
 	confSelClear $win $pos
-	mkEntryBox .@cadd "Edit $typ" "Edit the $ltyp:" \
+	mkEntryBox .@cadd "[$net name] - Edit $typ" "Edit the $ltyp:" \
 	  [list [list $typ $val]] \
 	  [list ok "doCAN $net $pos $var $win 0"] \
 	  [list default "doCAN $net $pos $var $win 1"] \
@@ -282,7 +282,7 @@ proc confAddServer {net win y} {
     set val [$win get [set pos [$win nearest $y]]]
     confDABtns $net
     switch *NEW* $val {
-	mkEntryBox .@cas$net {New Server} {Enter the new server details:} \
+	mkEntryBox .@cas$net "[$net name] - New Server" {Enter the new server details:} \
 	  [list [list hostname {}] [list port 6667] \
 	  [list {Server passwd} {}] [list {Op Nick} {}] \
 	  [list {Op passwd} {}]] [list ok "doCAS $net {} $pos $win 0"] \
@@ -292,7 +292,7 @@ proc confAddServer {net win y} {
 	set sid [lindex [lindex $lbdata($win) $pos] 1]
 	upvar #0 new$sid new
 	confSelClear $win $pos
-	mkEntryBox .@cas$net {Edit Server} {Edit the server details:} \
+	mkEntryBox .@cas$net "[$net name] - Edit Server" {Edit the server details:} \
 	  [list [list hostname $val] [list port $new(port)] \
 	  [list {Server passwd} $new(passwd)] \
 	  [list {Op Nick} $new(oper)] [list {Op passwd} $new(operpw)]] \
@@ -399,7 +399,7 @@ proc confAddFriend {net win y} {
     set val [lindex $xval 0]
     confDABtns $net
     switch *NEW* $val {
-	mkEntryBox .@can$net {New Friend} {Enter the new friend's nickname:} \
+	mkEntryBox .@can$net "[$net name] - [trans "new friend"]" {Enter the new friend's nickname:} \
 	  [list [list nickname {}] [list {User@Host Pattern} {}]] \
 	  [list ok "doCAF $net $pos $win {} 0"] \
 	  [list {Notify On} "doCAF $net $pos $win {} 1"] [list cancel {}]
@@ -408,7 +408,7 @@ proc confAddFriend {net win y} {
 	set id [lindex $xval 1]
 	upvar #0 new$id newu
 	set nf [$id notify]
-	mkEntryBox .@can$net {Edit Friend} {Edit the Friend's nickname:} \
+	mkEntryBox .@can$net "[$net name] - Edit Friend" {Edit the Friend's nickname:} \
 	  [list [list nickname $val] [list {User@Host Pattern} $newu(id)]] \
 	  [list ok "doCAF $net $pos $win $id [expr {!$nf}]"] \
 	  [list "Notify [expr {$nf ? {On} : {Off}}]" "doCAF $net $pos $win $id $nf"] \
@@ -471,12 +471,12 @@ proc doConfIgnore {net indx} {
 proc confAddIgnore {net win y} {
     set val [$win get [set pos [$win nearest $y]]]
     switch *NEW* $val {
-	mkEntryBox .@ci {New ignore} {Enter the nickname/username to ignore:} \
+	mkEntryBox .@ci "[$net name] - New ignore" {Enter the nickname/username to ignore:} \
 	  [list [list nickname {}]] [list ok "doCAI $net $pos $win"] \
 	  [list cancel {}]
     } default {
 	confSelClear $win $pos
-	mkEntryBox .@ci {Edit Nick} {Edit the nickname:} \
+	mkEntryBox .@ci "[$net name] - Edit Nick" {Edit the nickname:} \
 	  [list [list nickname $val]] [list ok "doCAI $net $pos $win"] \
 	  [list delete "confDel $net ignores $win"] [list cancel {}]
     }
